/*-
 * ============LICENSE_START=======================================================
 * ONAP Policy Engine
 * ================================================================================
 * Copyright (C) 2017, 2019 AT&T Intellectual Property. All rights reserved.
 * ================================================================================
 * Modifications Copyright (C) 2019 Samsung
 * ================================================================================
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 * ============LICENSE_END=========================================================
 */

package org.onap.policy.admin;

import static org.junit.Assert.assertFalse;
import static org.junit.Assert.assertNull;
import static org.junit.Assert.assertTrue;

import com.att.research.xacml.util.XACMLProperties;
import java.io.File;
import java.io.IOException;
import org.junit.FixMethodOrder;
import org.junit.Test;
import org.junit.runners.MethodSorters;

@FixMethodOrder(MethodSorters.NAME_ASCENDING)
public class CheckPdpPropertiesTest {

    @Test
    public final void test1NoPropertySet() throws IOException {
        System.setProperty(XACMLProperties.XACML_PROPERTIES_NAME, "noexistenfile.properties");
        assertFalse(CheckPdpProperties.validateId("http://localhost:8082/pdp/"));

        System.clearProperty(XACMLProperties.XACML_PROPERTIES_NAME);
        System.clearProperty("xacml.rest.pdp.idfile");
        assertFalse(CheckPdpProperties.validateId("http://localhost:8082/pdp/"));

        System.setProperty("xacml.rest.pdp.idfile", new File(".").getCanonicalPath() + File.separator + "src"
                + File.separator + "test" + File.separator + "resources" + File.separator + "idonotexist.properties");
        assertFalse(CheckPdpProperties.validateId("http://localhost:8082/pdp/"));

        System.setProperty("xacml.rest.pdp.idfile",
                new File(".").getCanonicalPath() + File.separator + "src" + File.separator + "test" + File.separator
                        + "resources" + File.separator + "doesnothaveproperties.atall");
        assertFalse(CheckPdpProperties.validateId("http://localhost:8082/pdp/"));

        System.setProperty("xacml.rest.pdp.idfile", new File(".").getCanonicalPath() + File.separator + "src"
                + File.separator + "test" + File.separator + "resources" + File.separator + "testbad.properties");
        assertFalse(CheckPdpProperties.validateId("http://localhost:8082/pdp/"));

        System.setProperty("xacml.rest.pdp.idfile", new File(".").getCanonicalPath() + File.separator + "src"
                + File.separator + "test" + File.separator + "resources" + File.separator + "empty.properties");
        assertFalse(CheckPdpProperties.validateId("http://localhost:8082/pdp/"));

        System.setProperty("xacml.rest.pdp.idfile",
                new File(".").getCanonicalPath() + File.separator + "src" + File.separator + "test" + File.separator
                        + "resources" + File.separator + "testnotenoughvalues.properties");
        assertFalse(CheckPdpProperties.validateId("http://localhost:8082/pdp/"));

        assertNull(CheckPdpProperties.getPdpMap());
        assertNull(CheckPdpProperties.getEncoding("http://localhost:8082/pdp/"));
    }

    @Test
    public final void test2CheckPdp() throws IOException {
        System.setProperty("xacml.rest.pdp.idfile", new File(".").getCanonicalPath() + File.separator + "src"
                + File.separator + "test" + File.separator + "resources" + File.separator + "test.properties");
        assertTrue(CheckPdpProperties.validateId("http://localhost:8082/pdp/"));
        assertTrue(CheckPdpProperties.getPdpMap().containsKey("http://localhost:8082/pdp/"));
        assertTrue(CheckPdpProperties.getEncoding("http://localhost:8082/pdp/").equals("dGVzdHBkcDphbHBoYTQ1Ng=="));
    }
}
